Installation
============

Required dependencies
---------------------

- Python (3.11 or later)
- `numpy <http://www.numpy.org/>`__
- `pandas <https://pandas.pydata.org/>`__
- `parse <https://pypi.org/project/parse/>`__

Instructions
------------

filefisher can be installed via conda/mamba:

.. code-block:: bash

    conda install -c conda-forge filefisher

or alternatively, using pip:

.. code-block:: bash

   python -m pip install filefisher
